@@ -17,8 +17,8 @@ package Dist::Zilla::Plugin::RecommendedPrereqs;
 # ABSTRACT: Look for comments recommending prerequisites
 #---------------------------------------------------------------------
 
-our $VERSION = '4.06';
-# This file is part of Dist-Zilla-Plugins-CJM 4.20 (August 24, 2013)
+our $VERSION = '4.21';
+# This file is part of Dist-Zilla-Plugins-CJM 4.21 (February 22, 2014)
 
 
 use 5.008;
@@ -61,6 +61,7 @@ sub register_prereqs
     my $files = $self->$method;
 
     foreach my $file (@$files) {
+      $self->log_debug("Checking " . $file->name);
       my $content = $file->content;
 
       while ($content =~ /^ [ \t]* \# [ \t]* (RECOMMEND|SUGGEST) [ \t]+ PREREQ:
@@ -101,9 +102,9 @@ Dist::Zilla::Plugin::RecommendedPrereqs - Look for comments recommending prerequ
 
 =head1 VERSION
 
-This document describes version 4.06 of
-Dist::Zilla::Plugin::RecommendedPrereqs, released August 24, 2013
-as part of Dist-Zilla-Plugins-CJM version 4.20.
+This document describes version 4.21 of
+Dist::Zilla::Plugin::RecommendedPrereqs, released February 22, 2014
+as part of Dist-Zilla-Plugins-CJM version 4.21.
 
 =head1 SYNOPSIS
 
@@ -155,11 +156,11 @@ or through the web interface at
 L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-Plugins-CJM >>.
 
 You can follow or contribute to Dist-Zilla-Plugins-CJM's development at
-L<< http://github.com/madsen/dist-zilla-plugins-cjm >>.
+L<< https://github.com/madsen/dist-zilla-plugins-cjm >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Christopher J. Madsen.
+This software is copyright (c) 2014 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
